@@ -9,3 +9,7 @@ pub fn infinispan_client() -> Infinispan {
 pub async fn run<R: ToHttpRequest>(request: &R) -> Response {
     infinispan_client().run(request).await.unwrap()
 }
+
+pub async fn read_body(response: Response) -> String {
+    response.text_with_charset("utf-8").await.unwrap()
+}
